<%Page path="/bits/header" PAGENAME="account" VERIFY%>
<%SetArg name="CB_URI" value={<%IdentifyUser/f
                                mode="check"
                                type="customer"
                                verified.path="/bits/commerce/account/customer-cb-uri"
                              %>}%>
<%SetArg name="USERNAME" value={<%Clipboard
                                  mode="show"
                                  name="<%CB_URI%>/name"
                                  default="Unknown"%>}%>
<%SetArg name="CUSTOMER_ID" value={<%FS
                                     mode="search"
                                     uri="/Customers"
                                     index_1="email"
                                     value_1="<%USERNAME%>"
                                     compare_1="eq"
                                     fields="*"
                                     path="/bits/account/customer_id"
                                  %>}%>

<DIV ALIGN="center"><H1>Edit Account</H1></DIV>

<DIV ALIGN="center">

<FORM METHOD="get" ACTION="edit.html">
<%Account
  mode="edit-object"
  uri="/Customers"
  id="<%CUSTOMER_ID%>"
  form.path="/bits/commerce/account/edit-form"
  success.path="/bits/commerce/account/edit-success"
%>
</FORM>

<%Condition
  default.path="/bits/commerce/account/footer-accounts"
  default.pass
%>

</DIV>

<%Page path="/bits/footer"%>
