<%Page path="/bits/header" PAGENAME="about"%>

<H1>About <%Utility mode="config-param" name="adminable/site_name/main"%></H1>
<P>

<%Utility mode="config-param" name="adminable/site_name/main"%>
specializes in industrial distribution of (in the words of our
President) tape, glue and sandpaper.  Simple, right?  It sure seems
like it.  However, at first glance, you might notice
<%Utility mode="config-param" name="adminable/site_name/main"%>
conducts business differently from other suppliers in this field.
<P>

In the world of just-in-time order fulfillment and supply chain models
based heavily in e-commerce,
<%Utility mode="config-param" name="adminable/site_name/main"%>
takes an approach that goes against the modern philosophies that
inventory costs too much to maintain. 
<%Utility mode="config-param" name="adminable/site_name/main"%>
maintains large inventories in 33 warehouses throughout the country.  
<P>

While other distributors base fulfillment on the ability of the
manufacturer to ship product at a moments notice,
<%Utility mode="config-param" name="adminable/site_name/main"%>
customers expect to stop at one of our locations and purchase
what they need.  Even customers from outside the area can expect
their items to be shipped that same day for next day delivery.
<P>

Most distributors are limited to base quantities set by the manufacturer
on all the items they sell.  That's because the manufacturers are used
to dealing with pallets and cases to begin with. 
<%Utility mode="config-param" name="adminable/site_name/main"%>
doesn't have those limitations.  Your order is fulfilled in our warehouse so if you
only need three tubes of Silicone and a sanding belt, as a customer, you
are not stuck with more material than you may be able to use before a
product expires.
<P>

This philosophy may not matter as much to organizations ordering large
quantities of products, but our "No Minimum Order" business practice
provides smaller organizations the buying capability of larger customers
without unused product setting on a shelf.
<P>

We would like you to remember our phone number (877-555-1212).  It's
displayed all over this site.  If your visit here isn't what you had
expected or you are having difficulty finding what you need, please call! 
Whether you know of us only through your visit to this website or have
been called on by one of our representatives,
<%Utility mode="config-param" name="adminable/site_name/main"%>
makes every effort to insure that when you need assistance, you will not become a
caller directed to voice mail or placed in a queue waiting for someone
to eventually get to you.  All phone calls are answered immediately! 
During the busiest of times when the product specialist lines are full,
your call is answered! Even the General Manager and President's phone
lines ring to insure that you get the information or product you need so
you can get back to doing business.
<P>

<%Utility mode="config-param" name="adminable/site_name/main"%>
looks at the process of doing business as a partnership.  The
level of any partnership with
<%Utility mode="config-param" name="adminable/site_name/main"%>
resides with our customers.  Whether it's the occasional cash
purchase or maintaining inventory for our customers,
<%Utility mode="config-param" name="adminable/site_name/main"%>
treats all of our customers as partners for
life.  We adapt to your business processes to insure that you continue
to receive the products you need to operate. 
<%Utility mode="config-param" name="adminable/site_name/main"%>
with the assistance of its subsidiary, Saunders Corporation can provide
product customization including die cut, printing, laminating and slitting
of materials we sell allowing the products to go direct to line for
manufacturers.
<P>

Even though
<%Utility mode="config-param" name="adminable/site_name/main"%>
functions a lot like a general store of days past,
it doesn't mean that we are without the technology to support any
organization.  We are fully functional in accepting E-commerce
transactions, EDI, Email, Purchase Orders and orders via Fax.  If you
give us a call, we can establish your account immediately and accept
your credit card or (what is almost unheard of these days) grant instant
credit on your first order!
<P>

If this sounds like the way you would like to do business, we welcome
you to give us the opportunity to become a part of the way your business
works.
<P>

<STRONG>Welcome to <%Utility mode="config-param" name="adminable/site_name/alt"%>!</STRONG>
<P>

<%Page path="/bits/footer"%>
