<%Page path="/bits/header-admin"%>

<CENTER><H1>Shipped Orders</H1></CENTER>
<P>

<%FS
  mode="search"
  uri="/Orders"

  index_1="status"
  compare_1="wq"
  value_1="shipped"

  orderby="-place_time"
  start_item={<%CgiParam/f name="start_item" default="1"%>}
  items_per_page={<%CgiParam/f name="items_per_page" default="10"%>}
  fields="*"

  header.path="/bits/commerce/admin/order/list-header"
  path="/bits/commerce/admin/order/list-row"
  footer.path="/bits/commerce/admin/order/list-footer"
  default.template={
    <DIV ALIGN="center"><EM>
    No shipped orders found.
    </EM></DIV>
  }
%>
<P>

<DIV ALIGN="center">
<%Condition
  default.path="/bits/commerce/admin/order/footer-orders"
  default.pass
%>
</DIV>

<%Page path="/bits/footer-admin"%>
