<%Page path="/bits/header" PAGENAME="order"%>
<%Order
  mode="clear"
  template="You have no items on order."
  sorry.template="You have no items on order."
  item.path="/bits/order/item"
%>
<%Page path="/bits/footer"%>
