<%Page path="/bits/header" PAGENAME="order" VERIFY%>
<%Order
  mode="add"
  path="/bits/order/order-confirm"
  sorry.template="You have no items on order."
  item.path="/bits/order/item-fixed"
%>
<%Page path="/bits/footer"%>
