<%Page path="/bits/header" PAGENAME="account" VERIFY%>
<%SetArg name="CB_URI" value={<%IdentifyUser/f
                                mode="check"
                                type="customer"
                                verified.path="/bits/commerce/account/customer-cb-uri"
                              %>}%>
<%SetArg name="USERNAME" value={<%Clipboard
                                  mode="show"
                                  name="<%CB_URI%>/name"
                                  default="Unknown"%>}%>
<%SetArg name="CUSTOMER_ID" value={<%FS
                                     mode="search"
                                     uri="/Customers"
                                     index_1="email"
                                     value_1="<%USERNAME%>"
                                     compare_1="eq"
                                     fields="*"
                                     path="/bits/account/customer_id"
                                  %>}%>

<DIV ALIGN="center"><H1>Order History</H1></DIV>
<P>

<DIV ALIGN="center">

<%Order
  mode="search"
  uri="/Orders"
  base.clipboard={<%IdentifyUser/f
                    mode="check"
                    type="customer"
                    verified.path="/bits/commerce/account/customer-cb-uri"
                  %>/object}

  index_1="customer_id"
  compare_1="wq"
  value_1="<%CUSTOMER_ID%>"

  orderby="-place_time"
  start_item={<%CgiParam/f name="start_item" default="1"%>}
  items_per_page={<%CgiParam/f name="items_per_page" default="10"%>}
  fields="*"

  header.path="/bits/order/list-header"
  path="/bits/order/list-row"
  footer.path="/bits/order/list-footer"
  default.template={<DIV ALIGN="center"><EM>No orders status found</EM></DIV>}
%>
<P>

<%Condition
  default.path="/bits/commerce/account/footer-accounts"
  default.pass
%>

</DIV>

<%Page path="/bits/footer"%>
