<%Page path="/bits/header-admin"%>

<DIV ALIGN="center"><H1>Site Administration Home</H1></DIV>
<P>

<DIV ALIGN="center">

<TABLE><TR><TD>
<LI><A HREF="/admin/order/"><STRONG>Orders</STRONG></A>
<P>
<LI><A HREF="/admin/account/"><STRONG>Accounts</STRONG></A>
<P>
</TD></TR></TABLE>

</DIV>

<%Page path="/bits/footer-admin"%>
